@@ -3,7 +3,7 @@ IMGO - Process, augment, and balance image data.
 ------------------------------------------------
 UPTOOLS module: 
 
-Last updated: version 2.3.2
+Last updated: version 2.3.4
 
 Classes
 -------
@@ -1339,7 +1339,7 @@ class Image_Dataset:
             raise Exception("Cannot normalize standardized data.")
         else:
             subsets = self.shadow
-
+            print("Normalizing...")
             for k, v in subsets.items():
                 if v[0] is None:
                     setattr(self, f"X_{k}", None)
@@ -1353,6 +1353,7 @@ class Image_Dataset:
             self.min_pv = self.min_pv / 255
             self.max_pv = self.max_pv / 255
             self.reduce = "norm"
+            print("Normalization complete.")
 
     #     ----------
 
@@ -1404,6 +1405,7 @@ class Image_Dataset:
                 self.min_pv = (self.min_pv - self.mu) / self.sigma
                 self.max_pv = (self.max_pv - self.mu) / self.sigma
                 self.reduce = "std"
+                print("Standardization complete.")
 
     #     ----------
 
